[jboss-cvs] JBossAS SVN: r57475 - projects/test/trunk/test/src/main/org/jboss/test

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Fri Oct 6 14:53:40 EDT 2006


Author: scott.stark at jboss.org
Date: 2006-10-06 14:53:38 -0400 (Fri, 06 Oct 2006)
New Revision: 57475

Modified:
   projects/test/trunk/test/src/main/org/jboss/test/JBossTestServices.java
Log:
Change the default deploy lib dir to output/lib rather than ../lib to work with the working dir being the project root

Modified: projects/test/trunk/test/src/main/org/jboss/test/JBossTestServices.java
===================================================================
--- projects/test/trunk/test/src/main/org/jboss/test/JBossTestServices.java	2006-10-06 18:19:36 UTC (rev 57474)
+++ projects/test/trunk/test/src/main/org/jboss/test/JBossTestServices.java	2006-10-06 18:53:38 UTC (rev 57475)
@@ -43,7 +43,7 @@
  * deploying ejb packages. You may supply the JNDI name under which the
  * RMIAdaptor interface is located via the system property jbosstest.server.name
  * default (jmx/rmi/RMIAdaptor) and the directory for deployable packages with
  * the system property jbosstest.deploy.dir (default ../lib).
  *
  * Should be subclassed to derive junit support for specific services integrated
  * into jboss.
@@ -164,7 +164,7 @@
    /**
     * Returns the deployment directory to use. This does it's best to figure out
     * where you are looking. If you supply a complete url, it returns it.
     * Otherwise, it looks for jbosstest.deploy.dir or if missing ../lib. Then it
     * tries to construct a file url or a url.
     *
     * @param filename                   name of the file/url you want
@@ -188,7 +188,7 @@
       String deployDir = System.getProperty("jbosstest.deploy.dir");
       if (deployDir == null)
       {
-         deployDir = "../lib";
+         deployDir = "output/lib";
       }
       String url = deployDir + "/" + filename;
       log.debug("Testing file: " + url);
@@ -262,7 +262,7 @@
 
    /**
     * Deploy a package with the main deployer. The supplied name is
     * interpreted as a url, or as a filename in jbosstest.deploy.lib or ../lib.
     *
     * @param name           filename/url of package to deploy.
     * @exception Exception  Description of Exception
@@ -334,7 +334,7 @@
 
    /**
     * Undeploy a package with the main deployer. The supplied name is
     * interpreted as a url, or as a filename in jbosstest.deploy.lib or ../lib.
     *
     * @param name           filename/url of package to undeploy.
     * @exception Exception  Description of Exception
@@ -43,7 +43,7 @@
  * RMIAdaptor interface is located via the system property jbosstest.server.name
  * default (jmx/rmi/RMIAdaptor) and the directory for deployable packages with
- * the system property jbosstest.deploy.dir (default ../lib).
+ * the system property jbosstest.deploy.dir (default output/lib).
  *
  * Should be subclassed to derive junit support for specific services integrated
@@ -164,7 +164,7 @@
     * Returns the deployment directory to use. This does it's best to figure out
     * where you are looking. If you supply a complete url, it returns it.
-    * Otherwise, it looks for jbosstest.deploy.dir or if missing ../lib. Then it
+    * Otherwise, it looks for jbosstest.deploy.dir or if missing output/lib. Then it
     * tries to construct a file url or a url.
     *
@@ -262,7 +262,7 @@
    /**
     * Deploy a package with the main deployer. The supplied name is
-    * interpreted as a url, or as a filename in jbosstest.deploy.lib or ../lib.
+    * interpreted as a url, or as a filename in jbosstest.deploy.lib or output/lib.
     *
     * @param name           filename/url of package to deploy.
@@ -334,7 +334,7 @@
    /**
     * Undeploy a package with the main deployer. The supplied name is
-    * interpreted as a url, or as a filename in jbosstest.deploy.lib or ../lib.
+    * interpreted as a url, or as a filename in jbosstest.deploy.lib or output/lib.
     *
     * @param name           filename/url of package to undeploy.




More information about the jboss-cvs-commits mailing list